@@ -1,6 +1,6 @@
 __all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint', 'RussianProfileObjectPoint',
            'ProfileObjectPoint', 'UserProfileIpExistsPoint', 'UnlimitedSetCreditScorePoint', 'DocumentPoint',
-           'SendSignPoint', 'ValidateSignPoint', 'AgreementPoint')
+           'SendSignPoint', 'ValidateSignPoint', 'AgreementPoint', 'SetCreditScorePoint')
 
 from expressmoney.api import *
 
